@@ -212,5 +212,8 @@ def rabbitmq(request):
         retry_delay=2,
     )
     wait()
-    rabbit_connection = pika.BlockingConnection(rabbit_params)
+    try:
+        rabbit_connection = pika.BlockingConnection(rabbit_params)
+    except pika.adapters.blocking_connection.exceptions.ConnectionClosed:
+        print "Be sure that you're connecting rabbitmq-server >= 2.8.4"
     return rabbit_connection
